aboutsummaryrefslogtreecommitdiff
path: root/Jellyfin.Server.Implementations/Item/BaseItemRepository.QueryBuilding.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Jellyfin.Server.Implementations/Item/BaseItemRepository.QueryBuilding.cs')
-rw-r--r--Jellyfin.Server.Implementations/Item/BaseItemRepository.QueryBuilding.cs6
1 files changed, 3 insertions, 3 deletions
diff --git a/Jellyfin.Server.Implementations/Item/BaseItemRepository.QueryBuilding.cs b/Jellyfin.Server.Implementations/Item/BaseItemRepository.QueryBuilding.cs
index 22a03dafa7..812b6ab59c 100644
--- a/Jellyfin.Server.Implementations/Item/BaseItemRepository.QueryBuilding.cs
+++ b/Jellyfin.Server.Implementations/Item/BaseItemRepository.QueryBuilding.cs
@@ -439,11 +439,11 @@ public sealed partial class BaseItemRepository
|| (e.TopParentId.HasValue && f.ItemId == e.TopParentId.Value))));
}
// Exclude alternate versions from counts. Alternate versions have
// OwnerId set (pointing to their primary) but no ExtraType.
if (!filter.IncludeOwnedItems)
{
- baseQuery = baseQuery.Where(e => e.OwnerId == null || e.ExtraType != null);
+ baseQuery = baseQuery.Where(e => e.PrimaryVersionId == null && (e.OwnerId == null || e.ExtraType != null));
}
return baseQuery;
@@ -439,11 +439,11 @@ public sealed partial class BaseItemRepository
|| (e.TopParentId.HasValue && f.ItemId == e.TopParentId.Value))));
}
- // Exclude alternate versions from counts. Alternate versions have
- // OwnerId set (pointing to their primary) but no ExtraType.
+ // Exclude alternate versions and owned non-extra items from counts.
+ // Alternate versions have PrimaryVersionId set (pointing to their primary).
if (!filter.IncludeOwnedItems)
{